/*
  Doc_Arduino - german Arduino Forum
  Arduino IDE 1.8.13
  Arduino Nano Every
  16.03.2021
  License: GNU GPLv3
  
  Beispiel mit der CCL – Configurable Custom Logic
*/
/*
  Arduino Nano Every PinOut (ATmega4809)
                  _
               __|_|__    
              |       |  
  (D13)  PE2  +       +  PE1  (D12)  
        3.3V  +       +  PE0  (D11)  
  (AREF) PD7  +       +  PB1  (D10)(~)(TCA0 Channel 1)
  (D14)  PD3  +       +  PB0  (D 9)(~)(TCA0 Channel 0)
  (D15)  PD2  +       +  PE3  (D 8)
  (D16)  PD1  +       +  PA1  (D 7) 
  (D17)  PD0  +       +  PF4  (D 6)(~)(TCB0)
  (D18)  PF2  +       +  PB2  (D 5)(~)(TCA0 Channel 2)
  (D19)  PF3  +       +  PC6  (D 4)  
  (D20)  PD4  +       +  PF5  (D 3)(~)(TCB1)  
  (D21)  PD5  +       +  PA0  (D 2) 
        5.0V  +       +  GND
       RESET  +       +  RESET
         GND  +       +  PC5  (D 0) RX1
         VIN  +       +  PC4  (D 1) TX1      
              |_______|  
*/
/*
           |    Event       |      CCL-LUTn     |
  Pin Port | Port | Channel | default | PortMux |
   0  PC5  |  0     2 or 3  |   ---       ---
   1  PC4  |  0     2 or 3  |   ---       ---
   2  PA0  |  0     0 or 1  |  0-IN0      ---
   3  PF5  |  1     4 or 5  |   ---       ---
   4  PC6  |  0     2 or 3  |   ---      1-OUT
   5  PB2  |  1     0 or 1  |   ---       ---
   6  PF4  |  1     4 or 5  |   ---       ---
   7  PA1  |  0     0 or 1  |  0-IN1      ---
   8  PE3  |  0     4 or 5  |   ---       ---
   9  PB0  |  1     0 or 1  |   ---       ---
  10  PB1  |  1     0 or 1  |   ---       ---
  11  PE0  |  0     4 or 5  |   ---       ---
  12  PE1  |  0     4 or 5  |   ---       ---
  13  PE2  |  0     4 or 5  |   ---       ---
  14  PD3  |  1     2 or 3  |  2-OUT      ---
  15  PD2  |  1     2 or 3  |  2-IN2      ---
  16  PD1  |  1     2 or 3  |  2-IN1      ---
  17  PD0  |  1     2 or 3  |  2-IN0      ---
  18  PF2  |  1     4 or 5  |  3-IN2      ---
  19  PF3  |  1     4 or 5  |  3-OUT      ---
  20  PD4  |  1     2 or 3  |   ---       ---
  21  PD5  |  1     2 or 3  |   ---       ---
*/

#include <NanoEveryPin.h>
/*
InputPin  <18> LUT3in2;
OutputPin <19> LUT3out;
*/
InputPin  <pinPD0> LUT2in0;     // alternative Pinnamen
InputPin  <pinPD1> LUT2in1;
InputPin  <pinPD2> LUT2in2;
OutputPin <pinPD3> LUT2out;
/*
InputPin  <17> LUT2in0;
InputPin  <16> LUT2in1;
InputPin  <15> LUT2in2;
OutputPin <14> LUT2out;
*/

void setup()
{
  /*
  LUT3in2.init(); LUT3in2.enablePullup(); LUT3in2.enableInvertIO();
  LUT3out.init(); 
  */
  LUT2in0.init(); LUT2in0.enablePullup(); LUT2in0.enableInvertIO();
  LUT2in1.init(); LUT2in1.enablePullup(); LUT2in1.enableInvertIO();
  LUT2in2.init(); LUT2in2.enablePullup(); LUT2in2.enableInvertIO();
  LUT2out.init(); 

  initCCLLUT2();
}

void loop()
{
  
}

void initCCLLUT2(void)
{
   CCL.LUT2CTRLB  = CCL_INSEL0_IO_gc;   // pin LUT2-IN0 input source, PD0
   CCL.LUT2CTRLB |= CCL_INSEL1_IO_gc;   // pin LUT2-IN1 input source, PD1
   CCL.LUT2CTRLC  = CCL_INSEL2_IO_gc;   // pin LUT2-IN2 input source, PD2
   
   //CCL.TRUTH2 = 128;                  // Configure Truth Table, AND
   //CCL.TRUTH2 = 254;                  // Configure Truth Table, OR
   CCL.TRUTH2 =  22;                    // Configure Truth Table, XOR

   CCL.LUT2CTRLA  = CCL_OUTEN_bm;       // enable Output LUT2, PD3
   CCL.LUT2CTRLA |= CCL_ENABLE_bm;      // enable LUT2
   
   CCL.CTRLA = CCL_ENABLE_bm;           // general enable CCL module
}


void initEventSystem(void)
{
  EVSYS.CHANNEL7 = EVSYS_GENERATOR_RTC_OVF_gc;    // connect 'RTC OVF' to channel 7
  EVSYS.USERADC0 = EVSYS_CHANNEL_CHANNEL7_gc;     // connect generator 'RTC OVF' with user 'ADC0' via channel 7
}
